AttriaxSkanUpdateResult class

Constructors

AttriaxSkanUpdateResult({required AttriaxSkanUpdateStatus status, String? message, int? fineValue, AttriaxSkanCoarseValue? coarseValue, bool? lockWindow, AttriaxSkanState? state})
const
AttriaxSkanUpdateResult.fromJson(Map<String, Object?> json)
factory
AttriaxSkanUpdateResult.fromPayload(Object? payload)
factory

Properties

coarseValue AttriaxSkanCoarseValue?
final
fineValue int?
final
hashCode int
The hash code for this object.
no setterinherited
lockWindow bool?
final
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state AttriaxSkanState?
final
status AttriaxSkanUpdateStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited