MethodChannelAttriax class
An implementation of AttriaxPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- AttriaxPlatform
- MethodChannelAttriax
Constructors
- MethodChannelAttriax({MethodChannel? channel, String logName = 'attriax.platform_interface'})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
collectInstallReferrer(
) → Future< AttriaxInstallReferrerContext> -
override
-
collectNativeContext(
{bool collectAdvertisingId = true}) → Future< AttriaxNativeContext> -
override
-
collectWebViewUserAgent(
) → Future< String?> -
override
-
consumePendingCrashReport(
) → Future< AttriaxPendingCrashReport?> -
override
-
getTrackingAuthorizationStatus(
) → Future< AttriaxTrackingAuthorizationStatus> -
override
-
missingPluginInstallReferrerContext(
MissingPluginException error) → AttriaxInstallReferrerContext -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openBrowserUrl(
{required Uri uri, required AttriaxResolvedUrlOpenMode openMode}) → Future< bool> -
override
-
platformExceptionInstallReferrerContext(
PlatformException error) → AttriaxInstallReferrerContext -
readAttributionClipboard(
) → Future< String?> -
override
-
requestTrackingAuthorization(
{Duration? timeout}) → Future< AttriaxTrackingAuthorizationStatus> -
override
-
setAutomaticCrashReportingEnabled(
{required bool enabled}) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateSkanConversionValue(
{required int fineValue, AttriaxSkanCoarseValue? coarseValue, bool lockWindow = false}) → Future< AttriaxSkanUpdateResult> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited